Samples Trimming
^^^^^^^^^^^^^^^^

Our workflows uses `Trimmomatic`_ for read trimming. The Jupyter notebooks uses some basic Trimmomatic options that need
to be modified depending on the FastQC quality control report generated for the sample.

.. _Trimmomatic: http://www.usadellab.org/cms/?page=trimmomatic